summaryrefslogtreecommitdiffstats
path: root/sys/arm/mv/mv_machdep.c
diff options
context:
space:
mode:
authorian <ian@FreeBSD.org>2014-01-05 22:36:34 +0000
committerian <ian@FreeBSD.org>2014-01-05 22:36:34 +0000
commit420aa503c6704f4bb0c18541b7c7c193388555e1 (patch)
treee83eb08af479512a00f04c4a944ab592618fc11b /sys/arm/mv/mv_machdep.c
parent6f9ebfa0c3159b8dd19fa1a837691a7deaaa3842 (diff)
downloadFreeBSD-src-420aa503c6704f4bb0c18541b7c7c193388555e1.zip
FreeBSD-src-420aa503c6704f4bb0c18541b7c7c193388555e1.tar.gz
Remove dev/fdt/fdt_pci.c, which was code specific to Marvell ARM SoCs,
related to setting up static device mappings. Since it was only used by arm/mv/mv_pci.c, it's now just static functions within that file, plus one public function that gets called only from arm/mv/mv_machdep.c.
Diffstat (limited to 'sys/arm/mv/mv_machdep.c')
-rw-r--r--sys/arm/mv/mv_machdep.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sys/arm/mv/mv_machdep.c b/sys/arm/mv/mv_machdep.c
index 5b2fbe7..7c0e7c1 100644
--- a/sys/arm/mv/mv_machdep.c
+++ b/sys/arm/mv/mv_machdep.c
@@ -294,11 +294,11 @@ out:
}
/*
* Supply a default do-nothing implementation of fdt_pci_devmap() via a weak
* alias. Many Marvell platforms don't support a PCI interface, but to support
* those that do, we end up with a reference to this function below, in
* initarm_devmap_init(). If "device pci" appears in the kernel config, the
- * real implementation of this function in dev/fdt/fdt_pci.c overrides the weak
+ * real implementation of this function in arm/mv/mv_pci.c overrides the weak
* alias defined here.
*/
int mv_default_fdt_pci_devmap(phandle_t node, struct arm_devmap_entry *devmap,
@@ -310,7 +310,7 @@ mv_default_fdt_pci_devmap(phandle_t node, struct arm_devmap_entry *devmap,
return (0);
}
-__weak_reference(mv_default_fdt_pci_devmap, fdt_pci_devmap);
+__weak_reference(mv_default_fdt_pci_devmap, mv_pci_devmap);
/*
* XXX: When device entry in devmap has pd_size smaller than section size,
@@ -379,7 +379,7 @@ initarm_devmap_init(void)
* XXX this should account for PCI and multiple ranges
* of a given kind.
*/
- if (fdt_pci_devmap(child, &fdt_devmap[i], MV_PCI_VA_IO_BASE,
+ if (mv_pci_devmap(child, &fdt_devmap[i], MV_PCI_VA_IO_BASE,
MV_PCI_VA_MEM_BASE) != 0)
return (ENXIO);
i += 2;
@@ -294,11 +294,11 @@ out:
}
/*
- * Supply a default do-nothing implementation of fdt_pci_devmap() via a weak
+ * Supply a default do-nothing implementation of mv_pci_devmap() via a weak
* alias. Many Marvell platforms don't support a PCI interface, but to support
* those that do, we end up with a reference to this function below, in
OpenPOWER on IntegriCloud